---
title: Setting up a Toggleable Side Panel in KDE Plasma 6
description: Creating a Raven-like side-panel in KDE Plasma 6 that can be toggled with a click using native plasma panels and Scriptinator.
synopsis: Creating a Raven-like side-panel in KDE Plasma 6 that can be toggled with a click using native plasma panels and Scriptinator.
date: 2024-03-18
tags:
  - GNU/Linux
  - KDE
imageURL: /img/sidePanel/sidePanel_copy.avif
imageAlt: A cropped screenshot of my plasma desktop showing a side-panel on the right side of the screen containing the clipboard history widget and the media player widget. On the bottom panel is the Scriptinator plugin, showing a tooltip the following title&#58; "Show Panel," and body text&#58; "Show the hidden right panel."
mastodon_id: "112119633092992081"
---
Since a brief tryst with [Ubuntu Budgie Edition](https://ubuntubudgie.org/), I've dearly missed its Raven side-panel, a special panel on the side of the screen that can be opened and closed with a click. As someone who *needs* a clean, minimal desktop, the workflow is just too perfect — when you have two or three widgets that you use frequently, but not frequently enough that they warrant permanent homes on a main panel, just stuff them into a disappearing side-panel that can be called with a quick key-combination or by clicking on an icon; It's a great way to keep things out of the way, but within reach, without having a permanently cluttered system tray that you might want to keep clear for things like email notifications.

[![A cropped screenshot of my plasma desktop showing a side-panel on the right side of the screen containing the clipboard history widget and the media player widget. On the bottom panel is the Scriptinator plugin, showing a tooltip the following title&#58; "Show Panel," and body text&#58; "Show the hidden right panel.](/img/sidePanel/sidePanel_copy.avif "My side panel, and the widget that launches it.")](/img/sidePanel/sidePanel_copy.avif)

There are some drawbacks; this workflow isn't well supported on KDE Plasma, so it's a bit of a faff to set up, and only a few widgets will display nicely on a wide side-panel. For instance, it would be a dream to have the KDE weather widget automatically take advantage of the horizontal space and display the information that would usually be in its dropdown, but what you get instead is a giant icon, for now at least. I use my side-panel for my clipboard history and the media player widget, both of which play nicely with a side-panel. Another niggle I have with it is that, as far as I know, there's no way to disable activation of the panel when your mouse pointer makes contact with the screen edge. This is a mild to moderate inconvenience when you're working with applications that have toolbars on the sides of the window, like design applications often do.

For me, personally, the drawbacks aren't so severe as to put me off of the workflow.

## Creating and configuring the panel
First, you'll need to create a panel. To do this, right click on an empty section of your desktop, and select "Add Panel > Empty Panel." When the panel appears, right click it and select "Enter Edit Mode." Set up your panel however you like, but you will need to set "Visibility" to "Auto Hide" and may want to give it a width of at least 400px or so.

[![](/img/sidePanel/panelSettings_copy.avif "The panel settings configuration window.")](/img/sidePanel/panelSettings_copy.avif)

## Setting up the script
Now, if you wanted to show and hide your panel with a keyboard shortcut, you can set up a focus shortcut in the panel settings window and stop here. If, like me, you want to toggle your panel by clicking on an icon somewhere, we're going to have to use a wee script, but don't worry, it's not as hard as it sounds and I'll take you through it step by step.

Before we can put our script together, we're going to need to know what the ID of our panel is. Open up KRunner with Alt+F2 or Alt+Space and run `plasma-interactiveconsole`. This will launch KDE's Desktop Shell Scripting Console. In the console, type `print(panelIds);` and click "Execute." Assuming you entered that in correctly, what you should see now in the output console beneath the text editor is a series of numbers — the ID numbers of our panels. Keep a note of these numbers.

[![The interactive console showing a series of panel IDs printed to the console.](/img/sidePanel/printIDs_copy.avif "Look at those IDs.")](/img/sidePanel/printIDs_copy.avif)

Clear the text editor and enter the following:

```javascript
let panel = panelById(401);

panel.hiding === "autohide" ? panel.hiding = "windowsgobelow" : panel.hiding = "autohide";
```
This will check if our panel is set to auto-hide; if it is, the script will set the panel to "windows go below" mode, otherwise it will set the panel to auto-hide.

Now to make use of those panel ID numbers. Which number corresponds to your new side-panel? While I can't be sure, chances are it's the last number on the list as we've just made the new panel a moment ago. So in the script above, where I have entered 401, enter the last number in your ID list and click "Execute." At this point, if the ID number is correct, your panel should appear; click "Execute" once more to hide it.

## Setting up the Scriptinator widget
Alright, we've got our script ready, so we just need one more thing in place: a button or icon that we can click on to show and hide the panel. Fortunately, we can use a widget called "Scriptinator" to provide just this. Right click on an empty area of your desktop or a panel, click "Add Widgets," and "Get New Widgets."

[![A cropped screenshot of the widgets panel with the "get new widgets" button at the top.](/img/sidePanel/getWidgets_copy.avif "Let's get that widget.")](/img/sidePanel/getWidgets_copy.avif)

From here, find and install Scriptinator. Once installed, simply drag it where you'd like it to live, either on your desktop, or on a panel. Once you've done that, right click on the widget and choose "Configure Scriptinator." Here, enter the path of the icon you'd like to use in "Custom icon full path;" I used `/usr/share/icons/breeze-dark/actions/22/sidebar-expand-right-symbolic.svg`. In "OnClick Script," enter the following:

```bash
qdbus org.kde.plasmashell /PlasmaShell evaluateScript ''
```
and between those single-quote marks, paste in the full script we put together in the Desktop Shell Scripting Console, like this:
```bash
qdbus org.kde.plasmashell /PlasmaShell evaluateScript 'let panel = panelById(401);

panel.hiding === "autohide" ? panel.hiding = "windowsgobelow" : panel.hiding = "autohide";'
```

[![](/img/sidePanel/Scriptinator_copy.avif "The Scriptinator configuration window.")](/img/sidePanel/Scriptinator_copy.avif)

Set up a tooltip if you like, hit apply, and test out your toggle button.

## Success!
If you've done everything correctly, you should see your side-panel appear when you click the widget and disappear when you click a second time. You may need to restart to see your icon applied to the widget; if you don't want to wait, you can drop the file path into "OnClick icon full path" in your Scriptinator configuration.
