---
title: "What Do We Expect from Fragrance? Natural Incense in an Unnatural World"
description: How our expectations influence the way we experience fragrance and where natural incense fits in.
date: 2024-12-18
tags:
  - Essays
  - Incense
  - Incense Making
synopsis: How our expectations influence the way we experience fragrance and where natural incense fits in.
imageURL: /img/incense_seal.webp
imageAlt: A burning incense seal in a flat brass censer.
mastodon_id: "113677779325283607"
---
Smoke was the first breath of early civilization, its rising plumes a synonym for human presence. This byproduct of life-sustaining flame has been constant companion to our evolution as a species, changing not only human lives, but [human bodies](https://www.psu.edu/news/research/story/where-theres-smoke-and-mutation-there-may-be-evolutionary-edge-humans). As the ubiquity of smoke rendered transparent to our ancestors' noses the once harsh notes of burning plant matter, there must have been a sense of magic when our forebears happened to toss a well-resinated tree branch or a fragrant herb upon the coals. It is little wonder, then, that the word "perfume" [stems from the Latin "perfumare,"](https://www.etymonline.com/word/perfume) translating to "through smoke."

## A rose by any other… chemical composition?
In these ancient times, the mention of a rose might have brought two fragrances to mind: that of a freshly blossomed rose in the bush, and that of the petals on the coals of a fire or burned in a censer. Later, enthusiasts of nerikoh or other forms of non-combustible incense would also become familiar with the fruity, acidic notes of gently heated rose petals. The situation is much changed today; for most people, the idea of the fragrance of rose is in no way related to incense-making traditions. Beautiful but aromatically impotent roses stuffed into plastic grocery store bins year-round aren't much help either. Today, synthesized ingredients like rose oxide, citronellol, or geraniol inform the average person's perception of how a rose smells; for those with expensive tastes, this perception may also be derived from a "natural" concentrate such as rose essential oil, wherein vast quantities of flowers are shoveled into a device and divested of volatile aromatic compounds via an industrial steam distillation process, which can result in [tiny yields, such as, for example: one part oil for every 3,000 parts roses](https://en.wikipedia.org/wiki/Rose_oil#adulteration).[^1]

In the incense making world, the siren song of these convenient ingredients is ever-present, with some even claiming that it's outright impossible to express the delicate fragrance of flower blossoms in combustible incense without them. While it is true that some fragrances cannot be expressed at all in this way, I do not believe that rose is among them, especially if we are willing to adjust our expectations and consider *what it means* to smell a rose. While there are many who would assert that the true fragrance of a material is to be found in its concentrated derivatives, given that a perfume might contain the strength of hundreds of roses while containing only a fraction of the many compounds that comprise the fragrance of a living rose, can it really be said that it effectively emulates what it is to smell a rose?

## Too much of a… thing
There have been many articles written on the field of "scent marketing," or "[sensory branding](https://en.wikipedia.org/wiki/Sensory_branding#Smell)," in which marketers manipulate the emotions of their customers through fragrance, with aim to bolster sales or steer brand perception through a medium that speaks to humankind on a most intimate and primal level. From perfumed love letters, to the occasional baker realizing that keeping something in the oven at all times certainly doesn't *hurt* sales, this is not a new phenomenon. What is new, however, is the ease with which shallow replicas of even the worlds scarcest aromatics can be whipped up with alacrity by a worker in a lab coat, and fragrance imbued into any material, any space, and any setting with little more than a few pumps of a spray bottle. This influences not only the way we think of aromatic ingredients and how their scents become known to us, but how we perceive fragrance itself: where once the acrid notes of burning wood were rendered transparent, now it is bright floral terpenes evocative of sunny spring mornings and bumblebees that fade into the periphery of our qualia; the fragrance of fresh citrus peel comes to evoke fluorescent lights and shiny tiled floors, that of vanilla becomes, well, *vanilla.*

Fragrance chemistry, the ability to synthesize compounds that speak directly to human emotion, must be among the most powerful of the cheat codes made available to us through the [Game Genie](https://en.wikipedia.org/wiki/Game_Genie#NES) of industrialization. While at first glance it seems too good to be true, you soon realize that the excitement of receiving a [P-Wing](https://www.mariowiki.com/P-Wing) is lost when you can simply spam the A-button to fly past a level; it's just not special any more—further, it loses its utility. Today there is no escape from fragrance. Your average American leaves the house with minty teeth, hair styled with wax scented with a synthetic approximation of eucalyptus and lime peel, wearing clothing washed with a "fresh laundry" fragranced detergent and dried with a lemon fabric softener; after bathing with sandalwood soap, they apply "sea salt and cedar" deodorant and a cologne featuring dozens of compounds, including a handful intending to approximate agarwood and bergamot (what the cologne adds here I struggle to imagine). In this veritable cacophony, most people fail to notice much of anything at all unless it's utterly redolent, and those who do are often those with sensory issues for whom fragrance is, more often than not, a special form of torture, inescapable so long as they wish to occupy a public space.

## Expecting redolence
In the noisily fragrant environment in which most of us live, it is interesting to consider those notes that do cause us to take notice: the humming of a cherry lip balm; the undulating tenor of a fresh bar of hand-soap; the [death metal pig-squealing](https://youtu.be/hCFBrQWYe3o?si=TWc0qzSkxNp_aOaw&t=50) of a Glade PlugIn®. In each case, our attention is arrested—violently seized and detained as hundreds of volatile organic compounds fight for access to our olfactory receptors like so many tired workers scrambling for a square foot of floor-space on the train during rush hour, only this time they compete in teams. Like music, fragrance has been demoted from something precious and closely associated with those things that we considered to be sacred—reduced to a dollar-store simulacrum stuffed into a mascot costume and made to flip a sign beside countless products that would otherwise fail to vacate store shelves on the merit of their performance alone. Certainly, some would point to the cheap ubiquity of fragrance as a sign that access has improved; after all, did the average medieval tradesman have a passing familiarity with the fragrance of sandalwood? I would rebut: do we?

In such a world, the fragrance of natural incense, incense free of unnaturally synthesized or concentrated aromatics, can be to our environment as the tune of a songbird is to the roar of passing traffic. In our homes, we can largely retreat from the soundtrack of daily life and create quiet, as far as noise is concerned. Creating quiet from fragrance, however, requires a greater degree of effort. Irrespective of our environment, much of the difficulty newcomers face in "listening to" natural incense stems from their expectations, warped by the ceaseless atonal chorus of fragrance around them. Chiefly, the hurdle that must be overcome is the idea of fragrance as a background element—a sort of olfactory elevator music; incense is, and deserves to be seen as, an activity in and of itself. When we adopt this mindset and listen with intention, it is remarkable what we are able to parse in even quite unsuited environments. Incense doesn't have to compete with the pumpkin-spice wax-melts of the world; these things serve different purposes.

## Fortissimo
Adding to their similarities, fragrance and music share a common loss: that of dynamics. The modulation of volume was historically an important piece of the emotional pull that music can have on its listeners; modern production largely omits this technique, barring a grand pause or two, in favor of a [loudness war](https://en.wikipedia.org/wiki/Loudness_war). As in classical music, classical fragrance employs this tool, creating one of the great points of pleasure of the incense format. Natural incense moves and changes, undulating in fragrance and strength, floating on the minute air currents of the room. Here, subtlety is as much an asset as is strength. I'm always disappointed to light a stick only to find that it spews a steady stream of oil-based fragrance into my living space, whether or not synthetics are involved. To be clear, I'm not inherently against the use of concentrates in incense, or even synthetics, which are often chemically identical to compounds found in natural materials. That said; for those seeking a sharp, cologne-like fragrance with unnatural clarity and strength, I believe incense is a poor choice.

While natural incense can indeed have plenty of fragrance, as an incense maker, I leave reaching for that 'beaten with a pillowcase of cinnamon sticks' projection to makers of scented candles and exfoliating bath soaps. If I intended to add to the cacophony, I'd reach for simpler means: a reed diffuser perhaps. Instead, what I aim to do is create an opportunity for respite, to create something beautiful that asks for attention rather than steals it. This approach respects the material realities of the ingredients that comprise incense, as well as the format itself. When one takes this approach, it's not long before one reaches the realization that rose petals carefully expressed in the smoke of a burning stick of incense do indeed smell of rose. So too do petals warming on a heater. So does rose oil, as well as burying your face in a fragrant blossom.

[^1]: To put this in more comprehensible terms, taking this ratio as gospel: if a quantity of rose petals equivalent to the weight of the average man living in the U.S.A. were to be distilled, the resulting essential oil would amount to *30 grams* of extremely concentrated oil.
